Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1657)

Unified Diff: services/ui/display/platform_screen.h

Issue 2503923003: Demonstrate external-window-mode in mus-demo (Closed)
Patch Set: Refactor, revert ozone_switches Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: services/ui/display/platform_screen.h
diff --git a/services/ui/display/platform_screen.h b/services/ui/display/platform_screen.h
index c266a57ee95adfc706c3baadb29653225479ad9a..d96cf30bdc326d65748de6ec84a459215b0b2a73 100644
--- a/services/ui/display/platform_screen.h
+++ b/services/ui/display/platform_screen.h
@@ -20,6 +20,11 @@ namespace display {
// attached physical displays.
class PlatformScreen {
public:
+ enum WindowMode {
+ WINDOW_MODE_EXTERNAL,
+ WINDOW_MODE_INTERNAL,
+ };
+
PlatformScreen();
virtual ~PlatformScreen();
@@ -32,10 +37,12 @@ class PlatformScreen {
// Triggers initial display configuration to start. On device this will
// configuration the connected displays. Off device this will create one or
rjkroege 2016/11/24 00:58:28 maybe fix the grammar while you're here. And the c
Tom (Use chromium acct) 2016/11/28 20:47:37 Done.
- // more fake displays and pretend to configure them. A non-null |delegate|
- // must be provided that will receive notifications when displays are added,
- // removed or modified.
- virtual void Init(PlatformScreenDelegate* delegate) = 0;
+ // more fake displays and pretend to configure them. In external window mode,
+ // no initial display will be created. A non-null |delegate| must be provided
+ // that will receive notifications when displays are added, removed or
+ // modified.
+ virtual void Init(PlatformScreenDelegate* delegate,
+ WindowMode window_mode = WINDOW_MODE_INTERNAL) = 0;
// Handle requests from the platform to close a display.
virtual void RequestCloseDisplay(int64_t display_id) = 0;

Powered by Google App Engine
This is Rietveld 408576698